@@ -555,7 +555,8 @@ private:
                              drag_current_target_window( None ),
                              drag_current_target_version( -1 ),
                              drag_current_proxy_target_window( None ),
-                             drop_pending( false ),
+                             drag_selection_pending( false ),
+                             drop_issued( false ),
                              mouse_button( Button1 ),
                              position_silent( false ),
                              position_silent_x( 0 ),
@@ -588,7 +589,8 @@ private:
 
         Window drag_current_proxy_target_window;
 
-        bool drop_pending;
+        bool drag_selection_pending;
+        bool drop_issued;
 
         unsigned int mouse_button;
 
