@@ -1,6 +1,6 @@
 /* guielement.cc
- * This file belongs to Worker, a filemanager for UNIX/X11.
- * Copyright (C) 2001-2005 Ralf Hoffmann.
+ * This file belongs to Worker, a file manager for UN*X/X11.
+ * Copyright (C) 2001-2015 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -18,10 +18,10 @@
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
  */
-/* $Id: guielement.cc,v 1.21 2005/05/23 18:44:03 ralf Exp $ */
 
 #include "guielement.h"
 #include "awindow.h"
+#include "bubblewindow.hh"
 
 const char *GUIElement::type="GUIElement";
 
@@ -39,7 +39,15 @@ GUIElement::GUIElement(AGUIX *taguix) : Widget( taguix )
 
 GUIElement::~GUIElement()
 {
-  destroy();
+    _aguix->clearBubbleHelpCandidate( this );
+
+    if ( auto bw = m_bubble_help_window.lock() ) {
+        bw->hide();
+        bw->unsetLinkedWidget();
+        _aguix->setBubbleHelpWindow( nullptr );
+    }
+
+    destroy();
 }
 
 void GUIElement::move(int tx,int ty)
@@ -84,9 +92,17 @@ bool GUIElement::isType(const char *qtype) const
 
 bool GUIElement::handleMessage(XEvent *E,Message *msg)
 {
-  // true falls die Message interessiert
-  // false wenn nicht
-  return false;
+    // true falls die Message interessiert
+    // false wenn nicht
+
+    if ( ! m_bubble_help_text.empty() ) {
+        if ( msg->type == EnterNotify &&
+             isParent( msg->window ) ) {
+            _aguix->setBubbleHelpCandidate( this );
+        }
+    }
+
+    return false;
 }
 
 void GUIElement::getPos(int *tx,int *ty) const
@@ -253,3 +269,22 @@ int GUIElement::callback( int val )
   }
   return 0;
 }
+
+void GUIElement::setBubbleHelpText( const std::string &help_text )
+{
+    m_bubble_help_text = help_text;
+}
+
+void GUIElement::openBubbleHelp()
+{
+    if ( ! m_bubble_help_text.empty() ) {
+        auto sp = std::make_shared< BubbleWindow >( _aguix, 10, 10, 50, 50, "", this );
+
+        m_bubble_help_window = sp;
+
+        sp->prepareHelpText( m_bubble_help_text );
+        sp->show();
+
+        _aguix->setBubbleHelpWindow( sp );
+    }
+}
