@@ -35,6 +35,7 @@ Message *AGUIX_allocMessage()
   msg->ack = false;
   msg->loop = 0;
   msg->keybuf = NULL;
+  msg->internal = false;
   return msg;
 }
 
@@ -51,9 +52,11 @@ AGMessage *AGUIX_allocAGMessage()
   AGMessage *agmsg;
 
   agmsg = (AGMessage*)_allocsafe( sizeof( AGMessage ) );
+
+  memset( &agmsg->dnd, 0, sizeof( agmsg->dnd ) );
+  
   agmsg->type = AG_NONE;
   agmsg->key.keybuf = NULL;
-  agmsg->dnd.specialinfo.rowDataP = NULL;
   agmsg->popupmenu.recursive_ids = NULL;
   agmsg->popupmenu.edit_content = NULL;
   return agmsg;
@@ -61,30 +64,30 @@ AGMessage *AGUIX_allocAGMessage()
 
 void AGUIX_freeAGMessage( AGMessage *agmsg )
 {
-  if ( agmsg != NULL ) {
-    if ( ( agmsg->type == AG_KEYPRESSED ) || ( agmsg->type == AG_KEYRELEASED ) ) {
-      if ( agmsg->key.keybuf != NULL ) _freesafe( agmsg->key.keybuf );
-    }
-    if ( ( agmsg->type == AG_DND_START ) ||
-	 ( agmsg->type == AG_DND_END ) ||
-	 ( agmsg->type == AG_DND_CANCEL ) ){
-      if ( agmsg->dnd.specialinfo.rowDataP != NULL )
-	delete (agmsg->dnd.specialinfo.rowDataP);
-    }
-    
-    if ( agmsg->type == AG_POPUPMENU_CLICKED ||
-         agmsg->type == AG_POPUPMENU_CLOSED ||
-         agmsg->type == AG_POPUPMENU_ENTRYEDITED ) {
-        if ( agmsg->popupmenu.recursive_ids != NULL ) {
-            delete agmsg->popupmenu.recursive_ids;
+    if ( agmsg != NULL ) {
+        if ( ( agmsg->type == AG_KEYPRESSED ) || ( agmsg->type == AG_KEYRELEASED ) ) {
+            if ( agmsg->key.keybuf != NULL ) _freesafe( agmsg->key.keybuf );
         }
-        if ( agmsg->popupmenu.edit_content != NULL ) {
-            delete agmsg->popupmenu.edit_content;
+        if ( agmsg->type == AG_DND_END ) {
+            if ( agmsg->dnd.specialinfo.rowDataP != NULL ) {
+                delete (agmsg->dnd.specialinfo.rowDataP);
+            }
+            delete agmsg->dnd.specialinfo.external_data;
         }
-    }
     
-    _freesafe( agmsg );
-  }
+        if ( agmsg->type == AG_POPUPMENU_CLICKED ||
+             agmsg->type == AG_POPUPMENU_CLOSED ||
+             agmsg->type == AG_POPUPMENU_ENTRYEDITED ) {
+            if ( agmsg->popupmenu.recursive_ids != NULL ) {
+                delete agmsg->popupmenu.recursive_ids;
+            }
+            if ( agmsg->popupmenu.edit_content != NULL ) {
+                delete agmsg->popupmenu.edit_content;
+            }
+        }
+    
+        _freesafe( agmsg );
+    }
 }
 
 AGMessage *AGUIX_allocAGMessage( Message *msg )
