@@ -59,6 +59,8 @@ typedef struct message
   Time time;
   char *keybuf;
   int x, y, width, height;
+
+  bool internal;
 } Message;
 
 enum {AG_NONE,AG_KEYPRESSED,AG_KEYRELEASED,AG_MOUSEPRESSED,AG_MOUSERELEASED,AG_MOUSECLICKED,AG_MOUSEMOVE,
@@ -67,7 +69,7 @@ enum {AG_NONE,AG_KEYPRESSED,AG_KEYRELEASED,AG_MOUSEPRESSED,AG_MOUSERELEASED,AG_M
       AG_STRINGGADGET_ACTIVATE,AG_STRINGGADGET_DEACTIVATE,AG_STRINGGADGET_OK,
       AG_STRINGGADGET_CANCEL,AG_STRINGGADGET_CONTENTCHANGE,AG_STRINGGADGET_CURSORCHANGE,
       AG_SIZECHANGED,
-      AG_DND_START,AG_DND_END,AG_DND_CANCEL,
+      AG_DND_END,
       AG_CYCLEBUTTONCLICKED,
 
       AG_FIELDLV_ONESELECT,
@@ -176,19 +178,17 @@ typedef struct agsizechange {
 
 typedef struct agdnd {
   int type;
-  int relx,rely;
-  Widget *element;
-  AWindow *window;
+  Widget *source_element;
+  Widget *target_element;
+  AWindow *target_awindow;
   struct {
-    void *voidP;
-    int value;
-    class FieldLVRowData *rowDataP;
+      int value;
+      class FieldLVRowData *rowDataP;
+      std::string *external_data;
   } specialinfo;
 } AGDND;
 
-typedef AGDND AGDNDSTART;
 typedef AGDND AGDNDEND;
-typedef AGDND AGDNDCANCEL;
 
 typedef struct agcyclebutton {
   int type;
