@@ -1,6 +1,6 @@
 /* text.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2007,2010 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -26,14 +26,14 @@
 
 const char *Text::type="Text";
 
-Text::Text(AGUIX *taguix,int tx,int ty,const char *ttext,int tcolor):GUIElement(taguix)
+Text::Text( AGUIX *taguix, int tx, int ty, const char *ttext ) : GUIElement( taguix )
 {
   this->text=dupstring(ttext);
   _x=tx;
   _y=ty;
   _w = taguix->getTextWidth( ttext ) + 1;
   _h=taguix->getCharHeight();
-  this->color=tcolor;
+  this->color = _aguix->getFaceCol_default_fg();
   bgset=false;
   font=NULL;
   bg = 0;
