@@ -1,6 +1,6 @@
 /* textview.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2015 Ralf Hoffmann.
+ * Copyright (C) 2005-2018 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -49,7 +49,8 @@ TextView::TextView( AGUIX *parent,
                                  tvcb( this ),
                                  _show_line_numbers( false ),
                                  m_buffer( 0 ),
-                                 m_show_frame( true )
+                                 m_show_frame( true ),
+                                 m_last_mouse_time( 0 )
 {
   hbar = vbar = NULL;
   cont = NULL;
@@ -271,6 +272,18 @@ bool TextView::handleMessage(XEvent *E,Message *msg)
   } else if ( msg->type == ButtonRelease && msg->window == win ) {
       if ( msg->button == Button1 ) {
           copySelectionToClipboard();
+
+          if ( _aguix->isDoubleClick( msg->time, m_last_mouse_time ) ) {
+              int mx, my;
+
+              _aguix->queryPointer( win, &mx, &my );
+
+              handleDoubleClick( mx, my );
+
+              m_last_mouse_time = 0;
+          } else {
+              m_last_mouse_time = msg->time;
+          }
       }
   }
 
@@ -958,6 +971,17 @@ void TextView::clearSelection()
     m_selection.end_uline = m_selection.end_offset = -1;
 }
 
+void TextView::selectAll()
+{
+    setSelectionStart( 0, 0 );
+
+    std::string line_str;
+
+    ts.getLine( ts.getNrOfLines() - 1, 0, line_str );
+
+    setSelectionEnd( ts.getNrOfUnwrappedLines() - 1, (int)line_str.size() );
+}
+
 void TextView::sizeChanged( int width, int height )
 {
     AWindow::sizeChanged( width, height );
@@ -1144,6 +1168,11 @@ bool TextView::handleKeyMessage( KeySym key,
 		redraw();
             }
             break;
+        case XK_a:
+            selectAll();
+            copySelectionToClipboard();
+            redraw();
+            break;
         default:
             break;
     }
@@ -1193,8 +1222,26 @@ std::pair< int, int > TextView::getTextPosForMousePos( int x, int y )
 
     if ( base_x < 0 ) base_x = 0;
 
-    int absolute_row = relative_row + vbar->getOffset();
+    int absolute_row;
 
+    if ( relative_row >= 0 ) {
+        absolute_row = relative_row + vbar->getOffset();
+    } else {
+        // stop at the first visible row
+        absolute_row = vbar->getOffset();
+        base_x = 0;
+    }
+
+    bool bottom_outside = false;
+
+    if ( absolute_row >= ts.getNrOfLines() ) {
+        absolute_row = ts.getNrOfLines() - 1;
+        bottom_outside = true;
+    } else if ( relative_row >= vbar->getMaxDisplay() ) {
+        absolute_row = vbar->getOffset() + vbar->getMaxDisplay() - 1;
+        bottom_outside = true;
+    }
+    
     std::pair<int,int> cur_line = ts.getRealLinePair( absolute_row );
 
     if ( cur_line.first < 0 ) return cur_line;
@@ -1214,7 +1261,12 @@ std::pair< int, int > TextView::getTextPosForMousePos( int x, int y )
 
     ts.getLine( absolute_row, 0, clicked_line );
 
-    int offset_length = ts.getAWidth().getStrlen4WidthMaxlen( clicked_line.c_str(), base_x / 2, base_x, NULL );
+    int offset_length;
+    if ( ! bottom_outside ) {
+        offset_length = ts.getAWidth().getStrlen4WidthMaxlen( clicked_line.c_str(), base_x / 2, base_x, NULL );
+    } else {
+        offset_length = (int)clicked_line.size();
+    }
 
     return std::make_pair( cur_line.first, prev_sublines_chars + offset_length );
 }
@@ -1266,3 +1318,57 @@ void TextView::showFrame( bool nv )
 {
     m_show_frame = nv;
 }
+
+void TextView::handleDoubleClick( int mx, int my )
+{
+    std::pair< int, int > cur = getTextPosForMousePos( mx, my );
+    std::string line_str;
+
+    if ( ts.getUnwrappedLine( cur.first, 0, -1, line_str ) != 0 ) {
+        return;
+    }
+
+    int start_pos = cur.second;
+    int end_pos = cur.second;
+    int word_start = start_pos;
+    int word_end = end_pos;
+
+    if ( start_pos < 0 || start_pos >= (int)line_str.size() ) return;
+    if ( end_pos < 0 || end_pos >= (int)line_str.size() ) return;
+    
+    for (;;) {
+        if ( std::isspace( line_str[ start_pos ] ) ) {
+            break;
+        }
+
+        word_start = start_pos;
+
+        UTF8::movePosToPrevChar( line_str.c_str(), start_pos );
+
+        if ( word_start == start_pos ) {
+            break;
+        }
+    }
+
+    for (;;) {
+        word_end = end_pos;
+
+        if ( end_pos >= (int)line_str.size() ) {
+            break;
+        }
+        if ( std::isspace( line_str[ end_pos ] ) ) {
+            break;
+        }
+
+        UTF8::movePosToNextChar( line_str.c_str(), end_pos );
+
+        if ( word_end == end_pos ) {
+            break;
+        }
+    }
+
+    setSelectionStart( cur.first, word_start );
+    setSelectionEnd( cur.first, word_end );
+    copySelectionToClipboard();
+    redraw();
+}
