@@ -1,6 +1,6 @@
 /* textview.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2015 Ralf Hoffmann.
+ * Copyright (C) 2005-2018 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -110,6 +110,7 @@ public:
   void setSelectionEnd( int unwrapped_line_nr, int offset );
   void getSelectionEnd( int &unwrapped_line_nr, int &offset ) const;
   void clearSelection();
+    void selectAll();
 
   void sizeChanged( int width, int height );
 
@@ -152,6 +153,8 @@ protected:
     std::pair< int, int > m_button_press_unwrapped_line_pos;
 
     bool m_show_frame;
+
+    Time m_last_mouse_time;
   
   void boxRedraw();
   void createContainer();
@@ -184,6 +187,8 @@ protected:
     std::pair< int, int >  getTextPosForMousePos( int x, int y );
 
     void copySelectionToClipboard();
+
+    void handleDoubleClick( int mx, int my );
 };
 
 #endif
