@@ -1,6 +1,6 @@
 /* chmodop.c
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -311,3 +311,12 @@ void ChModOp::setRequestFlags(bool nv)
   requestflags=nv;
 }
 
+bool ChModOp::isInteractiveRun() const
+{
+    return true;
+}
+
+void ChModOp::setInteractiveRun()
+{
+    requestflags = true;
+}
