@@ -1,6 +1,6 @@
 /* chownop.c
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -312,3 +312,12 @@ void ChOwnOp::setRequestFlags( bool nv )
   requestflags = nv;
 }
 
+bool ChOwnOp::isInteractiveRun() const
+{
+    return true;
+}
+
+void ChOwnOp::setInteractiveRun()
+{
+    requestflags = true;
+}
