@@ -1,6 +1,6 @@
 /* configtokens.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2003-2017 Ralf Hoffmann.
+ * Copyright (C) 2003-2018 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -362,6 +362,9 @@ struct mytoken tokenlist[]={
   { CLOSECURRENTTAB_WCP, "closecurrenttab" },
   { NEXTTAB_WCP, "nexttab" },
   { PREVTAB_WCP, "prevtab" },
+  { TOGGLELOCKSTATE_WCP, "togglelockstate" },
+  { MOVETABLEFT_WCP, "movetableft" },
+  { MOVETABRIGHT_WCP, "movetabright" },
   { CHANGELAYOUTOP_WCP, "changelayoutop" },
   { LISTVIEWWEIGHT_WCP, "listviewweight" },
   { INFIXSEARCH_WCP, "infixsearch" },
@@ -438,6 +441,8 @@ struct mytoken tokenlist[]={
   { DIRCOMPAREOP_WCP, "dircompareop" },
   { TABPROFILESOP_WCP, "tabprofilesop" },
   { EXTERNALVDIROP_WCP, "externalvdirop" },
+  { VDIR_PRESERVE_DIR_STRUCTURE_WCP, "vdirpreservedirstructure" },
+  { OPENTABMENUOP_WCP, "opentabmenuop" },
 };
 
 ArrayList *tokenlist_sorted = NULL;
