@@ -1,6 +1,6 @@
 /* copyop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2015 Ralf Hoffmann.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -47,6 +47,7 @@ CopyOp::CopyOp() : FunctionProto()
   request_flags=false;
   overwrite=COPYOP_OVERWRITE_NORMAL;
   preserve_attr=true;
+  vdir_preserve_dir_structure = false;
   adjust_relative_symlinks = COPYOP_ADJUST_SYMLINK_NEVER;
   ensure_file_permissions = LEAVE_PERMISSIONS_UNMODIFIED;
   hasConfigure = true;
@@ -69,6 +70,7 @@ CopyOp::duplicate() const
   ta->request_flags=request_flags;
   ta->overwrite=overwrite;
   ta->preserve_attr=preserve_attr;
+  ta->vdir_preserve_dir_structure = vdir_preserve_dir_structure;
   ta->adjust_relative_symlinks = adjust_relative_symlinks;
   ta->ensure_file_permissions = ensure_file_permissions;
   return ta;
@@ -133,6 +135,10 @@ CopyOp::save(Datei *fh)
   }
   fh->configPutPairBool( "preserveattr", preserve_attr );
 
+  if ( vdir_preserve_dir_structure == true ) {
+      fh->configPutPairBool( "vdirpreservedirstructure", vdir_preserve_dir_structure );
+  }
+  
   switch ( adjust_relative_symlinks ) {
       case COPYOP_ADJUST_SYMLINK_OUTSIDE:
           fh->configPutPair( "adjustrelativesymlinks", "outside" );
@@ -200,6 +206,7 @@ CopyOp::normalmodecopy( ActionMessage *am )
     trequest_dest=request_dest;
     toverwrite=overwrite;
     tpreserve_attr=preserve_attr;
+    tvdir_preserve_dir_structure = vdir_preserve_dir_structure;
     tadjust_relative_symlinks = adjust_relative_symlinks;
     tensure_file_permissions = ensure_file_permissions;
   }
@@ -352,6 +359,7 @@ CopyOp::normalmodecopy( ActionMessage *am )
         co->move=tmove;
         co->follow_symlinks=tfollow_symlinks;
         co->preserve_attr=tpreserve_attr;
+        co->vdir_preserve_dir_structure = tvdir_preserve_dir_structure;
 
         switch ( tadjust_relative_symlinks ) {
             case COPYOP_ADJUST_SYMLINK_OUTSIDE:
@@ -420,7 +428,7 @@ CopyOp::doconfigure(int mode)
   win->create();
   _freesafe(tstr);
 
-  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 11 ), true );
+  AContainer *ac1 = win->setContainer( new AContainer( win, 1, 12 ), true );
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
@@ -528,12 +536,15 @@ CopyOp::doconfigure(int mode)
   if(tw>w) w=tw;
   x=5;*/
 
+  auto vdirpreserve_cb = ac1->addWidget( new ChooseButton( aguix, 0, 0, 20, 20, ( vdir_preserve_dir_structure == true ) ? 1 : 0,
+                                                           catalog.getLocale( 1209 ), LABEL_RIGHT, 0 ), 0, 9, cincwnr );
+
   if(mode==0) {
     rfcb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( request_flags == true ) ? 1 : 0,
-						      catalog.getLocale( 294 ), LABEL_RIGHT, 0 ), 0, 9, cincwnr );
+						      catalog.getLocale( 294 ), LABEL_RIGHT, 0 ), 0, 10, cincwnr );
   }
 
-  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 10 );
+  AContainer *ac1_2 = ac1->add( new AContainer( win, 2, 1 ), 0, 11 );
   ac1_2->setMinSpace( 5 );
   ac1_2->setMaxSpace( -1 );
   ac1_2->setBorderWidth( 0 );
@@ -591,6 +602,9 @@ CopyOp::doconfigure(int mode)
               case XK_8:
                   ep_cyb->setOption( ( ep_cyb->getSelectedOption() + 1 ) % 4 );
                   break;
+              case XK_9:
+                  vdirpreserve_cb->setState( ( vdirpreserve_cb->getState() == true ) ? false : true );
+                  break;
               case XK_Return:
                 if ( cb->getHasFocus() == false ) {
                   endmode = 0;
@@ -617,6 +631,7 @@ CopyOp::doconfigure(int mode)
       tsame_dir = sdcb->getState();
       trequest_dest = rdcb->getState();
       tpreserve_attr = pacb->getState();
+      tvdir_preserve_dir_structure = vdirpreserve_cb->getState();
 
       switch ( ars_cyb->getSelectedOption() ) {
           case 1:
@@ -666,6 +681,7 @@ CopyOp::doconfigure(int mode)
       request_dest = rdcb->getState();
       request_flags = rfcb->getState();
       preserve_attr = pacb->getState();
+      vdir_preserve_dir_structure = vdirpreserve_cb->getState();
 
       switch ( ars_cyb->getSelectedOption() ) {
           case 1:
@@ -803,6 +819,11 @@ void CopyOp::setPreserveAttr(bool nv)
   preserve_attr=nv;
 }
 
+void CopyOp::setVdirPreserveDirStructure(bool nv)
+{
+  vdir_preserve_dir_structure = nv;
+}
+
 void CopyOp::setAdjustRelativeSymlinks( adjust_relative_symlinks_t nv )
 {
     adjust_relative_symlinks = nv;
@@ -812,3 +833,13 @@ void CopyOp::setEnsureFilePermissions( const CopyParams::EnsureFilePermissions &
 {
     ensure_file_permissions = nv;
 }
+
+bool CopyOp::isInteractiveRun() const
+{
+    return true;
+}
+
+void CopyOp::setInteractiveRun()
+{
+    request_flags = true;
+}
