@@ -1,6 +1,6 @@
 /* createsymlinkop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -337,3 +337,12 @@ void CreateSymlinkOp::setRequestFlags(bool nv)
   requestflags=nv;
 }
 
+bool CreateSymlinkOp::isInteractiveRun() const
+{
+    return true;
+}
+
+void CreateSymlinkOp::setInteractiveRun()
+{
+    requestflags = true;
+}
