@@ -1,6 +1,6 @@
 /* deleteop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2004,2008,2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -151,7 +151,7 @@ int DeleteOp::configure()
 
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(25))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(25));
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
   
@@ -160,7 +160,7 @@ int DeleteOp::configure()
   ac1->setMaxSpace( 5 );
 
   cb = (ChooseButton*)ac1->add( new ChooseButton( aguix, 0, 0, 20, 20, ( also_active == true ) ? 1 : 0,
-						  catalog.getLocale( 153 ), LABEL_RIGHT, 1, 0 ), 0, 0, cincwnr );
+						  catalog.getLocale( 153 ), LABEL_RIGHT, 0 ), 0, 0, cincwnr );
   
   AContainer *ac1_1 = ac1->add( new AContainer( win, 2, 1 ), 0, 1 );
   ac1_1->setMinSpace( 5 );
@@ -170,15 +170,11 @@ int DeleteOp::configure()
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   Button *cancelb = (Button*)ac1_1->add( new Button( aguix,
 						     0,
 						     0,
 						     catalog.getLocale( 8 ),
-						     1,
-						     0,
 						     0 ), 1, 0, cfix );
 
   win->setDoTabCycling( true );
@@ -260,29 +256,29 @@ DeleteOpWin::open()
   close();
   w=400;
   h=10;
-  window = new AWindow( aguix, 10, 10, w, h, 0, catalog.getLocaleCom( 25 ),
+  window = new AWindow( aguix, 10, 10, w, h, catalog.getLocaleCom( 25 ),
                         AWindow::AWINDOW_DIALOG );
   window->create();
   tx=5;
   ty=5;
-  sourcetext=(Text*)window->add(new Text(aguix,tx,ty,"",1));
+  sourcetext=(Text*)window->add(new Text(aguix,tx,ty,""));
   ismessage = true;
   ty+=sourcetext->getHeight()+5;
   bb1=(BevelBox*)window->add(new BevelBox(aguix,tx,ty,w-2*tx,2,0));
   ty+=bb1->getHeight()+5;
 
-  ttext=(Text*)window->add(new Text(aguix,tx,ty,catalog.getLocale(142),1));
+  ttext=(Text*)window->add(new Text(aguix,tx,ty,catalog.getLocale(142)));
   tx+=ttext->getWidth()+5;
-  files2gotext=(Text*)window->add(new Text(aguix,tx,ty,"",1));
+  files2gotext=(Text*)window->add(new Text(aguix,tx,ty,""));
   tx=5;
   ty+=ttext->getHeight()+5;
-  ttext=(Text*)window->add(new Text(aguix,tx,ty,catalog.getLocale(143),1));
+  ttext=(Text*)window->add(new Text(aguix,tx,ty,catalog.getLocale(143)));
   tx+=ttext->getWidth()+5;
-  dirs2gotext=(Text*)window->add(new Text(aguix,tx,ty,"",1));
+  dirs2gotext=(Text*)window->add(new Text(aguix,tx,ty,""));
   tx=5;
   ty+=ttext->getHeight()+5;
 
-  gsb=(SolidButton*)window->add(new SolidButton(aguix,tx+1,ty+1,w-2*(tx+1),"",2,3,0));
+  gsb=(SolidButton*)window->add(new SolidButton(aguix,tx+1,ty+1,w-2*(tx+1),"","button-special1-fg", "button-special1-bg",0));
   bb2=(BevelBox*)window->add(new BevelBox(aguix,tx,ty,w-2*tx,gsb->getHeight()+2,1));
   gsb->toFront();
   sbw=gsb->getWidth();
@@ -291,7 +287,7 @@ DeleteOpWin::open()
   bb3=(BevelBox*)window->add(new BevelBox(aguix,tx,ty,w-2*tx,2,0));
   ty+=bb3->getHeight()+5;
   cb = (Button*)window->add( new Button( aguix, tx, ty,
-					 catalog.getLocale( 8 ), 1, 0, 0 ) );
+					 catalog.getLocale( 8 ), 0 ) );
   cb->move(w/2-cb->getWidth()/2,cb->getY());
   ty+=cb->getHeight()+5;
   h=ty;
