@@ -88,7 +88,7 @@ void DMCacheEntryNWC::reload( int flags )
     // now apply old values
 
     DirSortSettings sorter;
-    sorter.setSortMode( SORT_NAME | SORT_DIRMIXED );
+    sorter.setSortMode( SORT_STRICT_NAME | SORT_DIRMIXED );
 
     sorter.check( m_entries );
     sorter.check( old_entries );
@@ -139,8 +139,9 @@ void DMCacheEntryNWC::applyOldSettings( std::vector< NWCEntrySelectionState > &n
             auto old_fse = old_es_it->getNWCEntry();
 
             if ( old_fse != NULL ) {
-                int comp = StringComparator::compare( old_fse->getFullname(),
-                                                      new_fse->getFullname() );
+                int comp = NWCEntrySelectionState::sortfunction( *old_es_it,
+                                                                 new_es,
+                                                                 SORT_STRICT_NAME | SORT_DIRMIXED );
 
                 if ( comp > 0 ) {
                     // old larger than new so skip to next new element
