@@ -106,7 +106,8 @@ int EnterDirOp::run( WPUContext *wpu, ActionMessage *msg )
                     lm1 = l1->getActiveMode();
                     if ( lm1 != NULL ) {
                         std::string res_str;
-                        if ( wpu->parse( dir, res_str, a_max( EXE_STRING_LEN - 1024, 256 ), false ) == WPUContext::PARSE_SUCCESS ) {
+                        if ( wpu->parse( dir, res_str, a_max( EXE_STRING_LEN - 1024, 256 ),
+                                         false, WPUContext::PERSIST_NOTHING ) == WPUContext::PARSE_SUCCESS ) {
                             std::list< RefCount< ArgClass > > args;
 
                             args.push_back( new StringArg( res_str ) );
