@@ -1,6 +1,6 @@
 /* goftpop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2014 Ralf Hoffmann.
+ * Copyright (C) 2005-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -458,3 +458,13 @@ std::vector<std::string> GoFTPOp::getAvailModules()
     
     return l;
 }
+
+bool GoFTPOp::isInteractiveRun() const
+{
+    return true;
+}
+
+void GoFTPOp::setInteractiveRun()
+{
+    requestflags = true;
+}
