@@ -1,6 +1,6 @@
 /* intviewop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2015 Ralf Hoffmann.
+ * Copyright (C) 2005-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -368,3 +368,13 @@ void InternalViewOp::setCustomFiles( std::string nv )
 {
   _custom_files = nv;
 }
+
+bool InternalViewOp::isInteractiveRun() const
+{
+    return true;
+}
+
+void InternalViewOp::setInteractiveRun()
+{
+    _request_flags = true;
+}
