@@ -1,6 +1,6 @@
 /* listermode.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -128,8 +128,8 @@ void ListerMode::lvbDoubleClicked()
 void ListerMode::runCommand( const std::string &command )
 {
     if ( m_commands.count( command ) > 0 &&
-         m_commands[command].getVal() != NULL ) {
-        m_commands[command]->callback();
+         m_commands[command] != NULL ) {
+        m_commands[command]();
     } else {
         std::string text = AGUIXUtils::formatStringToString( catalog.getLocale( 993 ),
                                                              command.c_str() );
@@ -141,16 +141,16 @@ void ListerMode::runCommand( const std::string &command )
 }
 
 void ListerMode::registerCommand( const std::string &command,
-                                  const RefCount< GenericCallback< void > > &callback )
+                                  std::function< void (void) > callback )
 {
-    m_commands[command] = callback;
+    m_commands[ command ] = callback;
 }
 
 void ListerMode::runCommand( const std::string &command, const std::list< RefCount< ArgClass > > &args )
 {
     if ( m_commands_with_args.count( command ) > 0 &&
-         m_commands_with_args[command].getVal() != NULL ) {
-        m_commands_with_args[command]->callback( args );
+         m_commands_with_args[command] != NULL ) {
+        m_commands_with_args[command]( args );
     } else {
         std::string text = AGUIXUtils::formatStringToString( catalog.getLocale( 993 ),
                                                              command.c_str() );
@@ -162,7 +162,7 @@ void ListerMode::runCommand( const std::string &command, const std::list< RefCou
 }
 
 void ListerMode::registerCommand( const std::string &command,
-                                  const RefCount< GenericCallbackArg< void, const std::list< RefCount< ArgClass > > & > > &callback )
+                                  const std::function< void ( const std::list< RefCount< ArgClass > > ) > callback )
 {
     m_commands_with_args[command] = callback;
 }
