@@ -1,6 +1,6 @@
 /* listermode.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2014 Ralf Hoffmann.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -29,6 +29,7 @@
 #include "lister.h"
 #include "nmspecialsourceext.hh"
 #include <map>
+#include <functional>
 
 class ArgClass;
 class Datei;
@@ -69,9 +70,9 @@ public:
     virtual void runCommand( const std::string &command );
     virtual void runCommand( const std::string &command, const std::list< RefCount< ArgClass > > &args );
     virtual void registerCommand( const std::string &command,
-                                  const RefCount< GenericCallback< void > > &callback );
+                                  std::function< void (void) > callback );
     virtual void registerCommand( const std::string &command,
-                                  const RefCount< GenericCallbackArg< void, const std::list< RefCount< ArgClass > > & > > &callback );
+                                  const std::function< void ( const std::list< RefCount< ArgClass > > ) > callback );
     virtual void runCommandWithStrArgs( const std::string &command_str );
 
     virtual bool pathsChanged( const std::set< std::string > changed_paths );
@@ -103,8 +104,8 @@ protected:
   static const char *type;
 
 private:
-    std::map< std::string, RefCount< GenericCallback< void > > > m_commands;
-    std::map< std::string, RefCount< GenericCallbackArg< void, const std::list< RefCount< ArgClass > > & > > > m_commands_with_args;
+    std::map< std::string, std::function< void( void ) > > m_commands;
+    std::map< std::string, std::function< void ( const std::list< RefCount< ArgClass > > ) > > m_commands_with_args;
 };
 
 #endif
