@@ -1,6 +1,6 @@
 /* modifytabsop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2009-2014 Ralf Hoffmann.
+ * Copyright (C) 2009-2018 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -99,6 +99,15 @@ ModifyTabsOp::save( Datei *fh )
         case PREV_TAB:
             fh->configPutPair( "tabaction", "prevtab" );
             break;
+        case TOGGLE_LOCK_STATE:
+            fh->configPutPair( "tabaction", "togglelockstate" );
+            break;
+        case MOVE_TAB_LEFT:
+            fh->configPutPair( "tabaction", "movetableft" );
+            break;
+        case MOVE_TAB_RIGHT:
+            fh->configPutPair( "tabaction", "movetabright" );
+            break;
         default:
             fh->configPutPair( "tabaction", "newtab" );
             break;
@@ -133,6 +142,17 @@ ModifyTabsOp::nm_tab_action( ActionMessage *am )
                     args.push_back( new IntArg( -1 ) );
                     lm1->runCommand( "switch_to_tab_direction", args );
                     break;
+                case TOGGLE_LOCK_STATE:
+                    lm1->runCommand( "toggle_lock_current_tab" );
+                    break;
+                case MOVE_TAB_LEFT:
+                    args.push_back( new IntArg( -1 ) );
+                    lm1->runCommand( "move_tab_direction", args );
+                    break;
+                case MOVE_TAB_RIGHT:
+                    args.push_back( new IntArg( 1 ) );
+                    lm1->runCommand( "move_tab_direction", args );
+                    break;
                 default:
                     lm1->runCommand( "new_tab" );
                     break;
@@ -173,6 +193,9 @@ ModifyTabsOp::configure()
     rcyb->addOption( catalog.getLocale( 853 ) );
     rcyb->addOption( catalog.getLocale( 854 ) );
     rcyb->addOption( catalog.getLocale( 855 ) );
+    rcyb->addOption( catalog.getLocale( 1212 ) );
+    rcyb->addOption( catalog.getLocale( 1215 ) );
+    rcyb->addOption( catalog.getLocale( 1216 ) );
     rcyb->resize( rcyb->getMaxSize(), rcyb->getHeight() );
     ac1_1->readLimits();
     switch ( m_tab_action ) {
@@ -185,6 +208,15 @@ ModifyTabsOp::configure()
         case PREV_TAB:
             rcyb->setOption( 3 );
             break;
+        case TOGGLE_LOCK_STATE:
+            rcyb->setOption( 4 );
+            break;
+        case MOVE_TAB_LEFT:
+            rcyb->setOption( 5 );
+            break;
+        case MOVE_TAB_RIGHT:
+            rcyb->setOption( 6 );
+            break;
         default:
             rcyb->setOption( 0 );
             break;
@@ -237,6 +269,15 @@ ModifyTabsOp::configure()
             case 3:
                 m_tab_action = PREV_TAB;
                 break;
+            case 4:
+                m_tab_action = TOGGLE_LOCK_STATE;
+                break;
+            case 5:
+                m_tab_action = MOVE_TAB_LEFT;
+                break;
+            case 6:
+                m_tab_action = MOVE_TAB_RIGHT;
+                break;
             default:
                 m_tab_action = NEW_TAB;
                 break;
