@@ -1,6 +1,6 @@
 /* nmcopyopdir.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2006,2008,2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -59,7 +59,7 @@ NM_CopyOp_Dir::~NM_CopyOp_Dir()
 }
 
 int
-NM_CopyOp_Dir::createSubDirs(struct copyorder *copyorder,unsigned long *gf,unsigned long *gd)
+NM_CopyOp_Dir::createSubDirs( std::shared_ptr< struct copyorder > co,unsigned long *gf,unsigned long *gd)
 {
   NM_CopyOp_Dir *cod1;
   bool enter;
@@ -73,9 +73,9 @@ NM_CopyOp_Dir::createSubDirs(struct copyorder *copyorder,unsigned long *gf,unsig
 
 /*TODO:Vorerst zu langsam, kann aber an MemSystem liegen, daher nochmal ohne
        das pruefen
-  if(copyorder->cowin!=NULL) {
-    copyorder->cowin->setmessage(verz->getDir(),1);
-    if ( copyorder->cowin->redraw() != 0 ) cancel = true;
+  if(co->cowin!=NULL) {
+    co->cowin->setmessage(verz->getDir(),1);
+    if ( co->cowin->redraw() != 0 ) cancel = true;
   }*/
 
   for ( Verzeichnis::verz_it fe_it1 = verz->begin();
@@ -88,14 +88,14 @@ NM_CopyOp_Dir::createSubDirs(struct copyorder *copyorder,unsigned long *gf,unsig
         // fe is a dir, check if it is a link and take it only when follow_symlinks==true
 	// entry is a dir so it cannot be a corrupt link so no need to check
         if(fe->isLink==false) enter=true;
-        else if(copyorder->follow_symlinks==true) enter=true;
+        else if(co->follow_symlinks==true) enter=true;
       }
       if(enter==true) {
         // fe is a dir so creating corresponding entry
         cod1=new NM_CopyOp_Dir(fe);
         if ( cod1->user_abort == false ) {
           // recursive call
-          if(cod1->createSubDirs(copyorder,gf,gd)!=0) cancel=true;
+          if(cod1->createSubDirs(co,gf,gd)!=0) cancel=true;
         } else cancel = true;
         // add the values from this subdir to this dir
         files+=cod1->files;
@@ -109,17 +109,17 @@ NM_CopyOp_Dir::createSubDirs(struct copyorder *copyorder,unsigned long *gf,unsig
         dirs++;
         (*gd)++;
 
-        if(copyorder->cowin!=NULL) {
-          copyorder->cowin->set_files_to_copy(*gf);
-          copyorder->cowin->set_dirs_to_copy(*gd);
-          if(copyorder->cowin->redraw()!=0) cancel=true;
+        if(co->cowin!=NULL) {
+          co->cowin->set_files_to_copy(*gf);
+          co->cowin->set_dirs_to_copy(*gd);
+          if ( co->cowin->redraw() & 1 ) cancel = true;
         }
       } else {
         // is not dir (mostly a file but can also be links ...)
         files++;
         (*gf)++;
         if ( ( fe->isLink == true ) &&
-             ( copyorder->follow_symlinks == true ) &&
+             ( co->follow_symlinks == true ) &&
              ( fe->isCorrupt == false ) ) {
 	  bytes += fe->dsize();
         } else {
