@@ -192,6 +192,10 @@ int NWCEntrySelectionState::sortfunction( const NWCEntrySelectionState &e1,
           comp = StringComparator::compare( fse1->getFullname(),
                                             fse2->getFullname() );
           break;
+      case SORT_STRICT_NAME:
+          comp = strcmp( fse1->getFullname().c_str(),
+                         fse2->getFullname().c_str() );
+          break;
       case SORT_SIZE:
           s1 = -1;
           s2 = -1;
