@@ -695,7 +695,8 @@ void OwnOp::externprog( WPUContext *wpu, ActionMessage *msg )
 
             for ( int loopnr = 1;; loopnr++ ) {
                 std::string res_str;
-                if ( wpu->parse( com_str, res_str, EXE_STRING_LEN - strlen( tmpoutput ) - 3 ) == WPUContext::PARSE_SUCCESS ) {
+                if ( wpu->parse( com_str, res_str, EXE_STRING_LEN - strlen( tmpoutput ) - 3,
+                                 true, WPUContext::PERSIST_ALL ) == WPUContext::PARSE_SUCCESS ) {
                     string1 = Worker_secureCommandForShell( res_str.c_str() );
                     if ( string1.length() > 0 ) {
                         if ( ownstart == OWNOP_SHOW_OUTPUT ||
