@@ -1011,3 +1011,13 @@ void SetFilterOp::cleanUpPopUp()
         m_popup_menu = NULL;
     }
 }
+
+bool SetFilterOp::isInteractiveRun() const
+{
+    return true;
+}
+
+void SetFilterOp::setInteractiveRun()
+{
+    request_flags = true;
+}
