@@ -74,6 +74,9 @@ public:
   void popupCallback( AGMessage *msg );
 
     static std::list< std::string > getHistory();
+
+    bool isInteractiveRun() const;
+    void setInteractiveRun();
 protected:
   static const char *name;
   // Infos to save
