@@ -264,7 +264,9 @@ StartProgOp::startprog( WPUContext *wpu, ActionMessage *am )
         std::string res_str;
         if ( wpu->parse( m1->_command.c_str(),
                          res_str,
-                         EXE_STRING_LEN - strlen( tmpoutput ) - 3 ) == WPUContext::PARSE_SUCCESS ) {
+                         EXE_STRING_LEN - strlen( tmpoutput ) - 3,
+                         true,
+                         WPUContext::PERSIST_FLAGS ) == WPUContext::PARSE_SUCCESS ) {
             string1 = Worker_secureCommandForShell( res_str.c_str() );
         }
 
