@@ -1,6 +1,6 @@
 /* textstoragefile.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2005-2007,2011 Ralf Hoffmann.
+ * Copyright (C) 2005-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -31,12 +31,14 @@
 
 TextStorageFile::TextStorageFile( const std::string &filename,
                                   const RefCount<AWidth> &lencalc,
-                                  int initial_size ) : m_tss( "", lencalc ),
-                                                       m_filename( filename ),
-                                                       m_current_size( 64 * 1024 ),
-                                                       m_lencalc( lencalc ),
-                                                       m_incomplete_file( true ),
-                                                       m_file_size( -1 )
+                                  int initial_size,
+                                  enum TextStorageString::text_storage_converion convert ) : m_tss( "", lencalc ),
+                                                                                             m_filename( filename ),
+                                                                                             m_current_size( 64 * 1024 ),
+                                                                                             m_lencalc( lencalc ),
+                                                                                             m_incomplete_file( true ),
+                                                                                             m_file_size( -1 ),
+                                                                                             m_convert( convert )
 {
     if ( initial_size > 0 && initial_size <= 1 * 1024 * 1024 * 1024 ) {
         m_current_size = initial_size;
@@ -136,27 +138,8 @@ void TextStorageFile::readFile()
         } while ( last_read > 0 && read_bytes < buffer_size );
 
         if ( read_bytes > 0 || ( read_bytes == 0 && last_read >= 0 ) ) {
-
-            // tab replacing
-            std::string notab_buffer;
-      
-            for ( int i = 0; i < read_bytes; i++ ) {
-                if ( buffer[i] != '\t' ) {
-                    // ignore \r from dos files
-                    if ( buffer[i] != '\r' ) {
-                        notab_buffer += buffer[i];
-                    }
-                } else {
-                    //TODO currently I replace tabs with 8 spaces
-                    //  In the future I hope I can make some GUI improvements
-                    //  so it will not draw tabs but align the next character
-                    //  at the next tab stop
-                    notab_buffer.append( 8, ' ' );
-                }
-            }
-
             //      m_tss = TextStorageString( buffer, read_bytes );
-            m_tss = TextStorageString( notab_buffer, m_lencalc, m_tss.getLineLimit() );
+            m_tss = TextStorageString( buffer, read_bytes, m_lencalc, m_tss.getLineLimit(), m_convert );
 
             // try to read another byte to check for EOF
             // (it could be done by asking for the actual size
@@ -197,6 +180,11 @@ void TextStorageFile::readMore( int size )
     readFile();
 }
 
+void TextStorageFile::reloadFile()
+{
+    readFile();
+}
+
 bool TextStorageFile::incompleteFile()
 {
     return m_incomplete_file;
@@ -227,6 +215,26 @@ int TextStorageFile::getUnwrappedLine( int line_nr,
                                    return_line );
 }
 
+int TextStorageFile::getUnwrappedLineRaw( int line_nr,
+                                          unsigned int offset,
+                                          int len,
+                                          std::string &return_line ) const
+{
+    return m_tss.getUnwrappedLineRaw( line_nr,
+                                      offset,
+                                      len,
+                                      return_line );
+}
+
+int TextStorageFile::getUnwrappedLineRaw( int line_nr,
+                                          unsigned int offset,
+                                          std::string &return_line ) const
+{
+    return m_tss.getUnwrappedLineRaw( line_nr,
+                                      offset,
+                                      return_line );
+}
+
 std::pair< std::pair< int, int >, int > TextStorageFile::getLineForOffset( int unwrapped_line_nr, int line_offset ) const
 {
     return m_tss.getLineForOffset( unwrapped_line_nr,
@@ -250,3 +258,8 @@ int TextStorageFile::getCurrentSize() const
 {
     return m_current_size;
 }
+
+void TextStorageFile::setConvertMode( enum TextStorageString::text_storage_converion convert )
+{
+    m_tss.setConvertMode( convert );
+}
