@@ -1,6 +1,6 @@
 /* togglelistermodeop.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2005,2011,2013 Ralf Hoffmann.
+ * Copyright (C) 2001-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -125,7 +125,7 @@ ToggleListermodeOp::configure()
   
   tstr=(char*)_allocsafe(strlen(catalog.getLocale(293))+strlen(catalog.getLocaleCom(39))+1);
   sprintf(tstr,catalog.getLocale(293),catalog.getLocaleCom(39));
-  win = new AWindow( aguix, 10, 10, 10, 10, 0, tstr, AWindow::AWINDOW_DIALOG );
+  win = new AWindow( aguix, 10, 10, 10, 10, tstr, AWindow::AWINDOW_DIALOG );
   win->create();
   _freesafe(tstr);
 
@@ -133,9 +133,9 @@ ToggleListermodeOp::configure()
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
 
-  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 112 ), 1 ), 0, 0, cincwnr );
+  ac1->add( new Text( aguix, 0, 0, catalog.getLocale( 112 ) ), 0, 0, cincwnr );
 
-  cyb = (CycleButton*)ac1->add( new CycleButton( aguix, 0, 0, 100, 1, 0, 0 ), 0, 1, cincw );
+  cyb = (CycleButton*)ac1->add( new CycleButton( aguix, 0, 0, 100, 0 ), 0, 1, cincw );
   for ( i = 0; i < Worker::getMaxModeNr(); i++ ) {
     cyb->addOption( Worker::getLocaleNameOfMode( i ) );
   }
@@ -151,15 +151,11 @@ ToggleListermodeOp::configure()
                                                 0,
                                                 0,
                                                 catalog.getLocale( 11 ),
-                                                1,
-                                                0,
                                                 0 ), 0, 0, cfix );
   Button *cb = (Button*)ac1_2->add( new Button( aguix,
 						0,
 						0,
 						catalog.getLocale( 8 ),
-						1,
-						0,
 						0 ), 1, 0, cfix );
   
   win->setDoTabCycling( true );
