@@ -1,6 +1,6 @@
 /* virtualdirmode_copy.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2013-2015 Ralf Hoffmann.
+ * Copyright (C) 2013-2018 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -31,7 +31,7 @@
 #include "nmcopyopdir.hh"
 #include "nwc_path.hh"
 #include "copystate.hh"
-#include <iostream>
+#include "nwc_os_makedirs.hh"
 
 const static int BGCOPY_UPDATE_TIMEOUT ( 1000 / 25 );
 
@@ -127,6 +127,8 @@ void VirtualDirMode::copy( std::shared_ptr< struct copyorder > co )
 
     {
         std::list< NM_specialsourceExt > copylist;
+        std::string source_base_dir;
+
         switch ( co->source ) {
             case copyorder::COPY_SPECIAL:
                 copySourceList( co->sources,
@@ -134,16 +136,48 @@ void VirtualDirMode::copy( std::shared_ptr< struct copyorder > co )
                 break;
             case copyorder::COPY_ONLYACTIVE:
                 getSelFiles( copylist, LM_GETFILES_ONLYACTIVE, false );
+                if ( ! currentDirIsReal() ) {
+                    source_base_dir = getCurrentDirectory();
+                }
                 break;
             default:  // all selected entries
                 getSelFiles( copylist, LM_GETFILES_SELORACT, false );
+                if ( ! currentDirIsReal() ) {
+                    source_base_dir = getCurrentDirectory();
+                }
                 break;
         }
         for ( auto &it : copylist ) {
             if ( ! it.entry() ) continue;
 
             if ( check_for_bg_copy_collision( it.entry()->fullname, cs ) == false ) {
-                cc->registerFEToCopy( *it.entry(), it.getID() );
+                std::vector< NWC::OS::deep_dir_info > file_base_segments;
+
+                if ( co->vdir_preserve_dir_structure &&
+                     ! source_base_dir.empty() ) {
+                    std::string file_base;
+
+                    file_base = NWC::Path::get_extended_basename( source_base_dir,
+                                                                  NWC::Path::dirname( it.entry()->fullname ) );
+
+                    int res = NWC::OS::prepare_deep_dir_info( source_base_dir,
+                                                              file_base,
+                                                              file_base_segments );
+
+                    if ( res != 0 ) {
+                        std::string buttons = catalog.getLocale( 8 );
+
+                        std::string text = AGUIXUtils::formatStringToString( catalog.getLocale( 1211 ),
+                                                                             it.entry()->fullname );
+
+                        cowin->request( catalog.getLocale( 123 ), text.c_str(), buttons.c_str() );
+                        cc->setCancel( true );
+                        break;
+                    }
+                }
+
+                cc->registerFEToCopy( *it.entry(), it.getID(),
+                                      file_base_segments );
             } else {
                 cc->setCancel( true );
             }
