@@ -1,6 +1,6 @@
 /* wconfig.h
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2016 Ralf Hoffmann.
+ * Copyright (C) 2001-2017 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -302,11 +302,13 @@ public:
       FONT_X11_LEFT,
       FONT_X11_RIGHT,
       FONT_X11_TEXTVIEW,
+      FONT_X11_STATEBAR,
       FONT_XFT_GLOBAL,
       FONT_XFT_BUTTONS,
       FONT_XFT_LEFT,
       FONT_XFT_RIGHT,
-      FONT_XFT_TEXTVIEW
+      FONT_XFT_TEXTVIEW,
+      FONT_XFT_STATEBAR
   } font_type_t;
 
   void setFontName( font_type_t fonttype, const std::string &name );
