@@ -1,6 +1,6 @@
 /* wconfig_color.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2006-2008,2011 Ralf Hoffmann.
+ * Copyright (C) 2006-2014 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -54,20 +54,20 @@ ColorPanel::ColorPanel( AWindow &basewin, WConfig &baseconfig ) : WConfigPanel(
   rsb = NULL;
   rvb = NULL;
   rhb = NULL;
-  _tv_fg_b = NULL;
-  _tv_bg_b = NULL;
-  _tv_hfg_b = NULL;
-  _tv_hbg_b = NULL;
-  _tv_sel_fg_b = NULL;
-  _tv_sel_bg_b = NULL;
-  _tv_cols_sb = NULL;
-  _tv_high_sb = NULL;
-  _tv_sel_sb = NULL;
+
+  m_faces_lv = nullptr;
+
+  m_face_modify = nullptr;
+  m_face_unset = nullptr;
+  m_face_default = nullptr;
+
+  m_facedb_copy = nullptr;
 }
 
 ColorPanel::~ColorPanel()
 {
   delete tempconfig;
+  delete m_facedb_copy;
 }
 
 int ColorPanel::create()
@@ -78,7 +78,7 @@ int ColorPanel::create()
   
   Panel::create();
 
-  AContainer *ac1 = setContainer( new AContainer( this, 1, 13 ), true );
+  AContainer *ac1 = setContainer( new AContainer( this, 1, 14 ), true );
   ac1->setMinSpace( 5 );
   ac1->setMaxSpace( 5 );
   
@@ -96,10 +96,10 @@ int ColorPanel::create()
                                                     _baseconfig.getStatusbar( 0 ),
                                                     _baseconfig.getStatusbar( 1 ),
                                                     false ), 0, 0, AContainer::CO_INCW );
-  sbvb = (Button*)ac1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 1, 0, 0 ),
+  sbvb = (Button*)ac1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 0 ),
                               1, 0, AContainer::CO_FIX );
   sbvb->connect( this );
-  sbhb = (Button*)ac1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 1, 0, 0 ),
+  sbhb = (Button*)ac1_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 0 ),
                               2, 0, AContainer::CO_FIX );
   sbhb->connect( this );
 
@@ -114,10 +114,10 @@ int ColorPanel::create()
                                                       _baseconfig.getSelLVB( 0 ),
                                                       _baseconfig.getSelLVB( 1 ), false ),
                                      0, 0, AContainer::CO_INCW );
-  slvbvb = (Button*)ac1_2->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 1, 0, 0 ),
+  slvbvb = (Button*)ac1_2->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 0 ),
                                 1, 0, AContainer::CO_FIX );
   slvbvb->connect( this );
-  slvbhb = (Button*)ac1_2->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 1, 0, 0 ),
+  slvbhb = (Button*)ac1_2->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 0 ),
                                 2, 0, AContainer::CO_FIX );
   slvbhb->connect( this );
 
@@ -130,10 +130,10 @@ int ColorPanel::create()
                                                       _baseconfig.getUnselLVB( 0),
                                                       _baseconfig.getUnselLVB( 1 ), false ),
                                      0, 0, AContainer::CO_INCW );
-  ulvbvb = (Button*)ac1_3->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 1, 0, 0 ),
+  ulvbvb = (Button*)ac1_3->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 0 ),
                                 1, 0, AContainer::CO_FIX );
   ulvbvb->connect( this );
-  ulvbhb = (Button*)ac1_3->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 1, 0, 0 ),
+  ulvbhb = (Button*)ac1_3->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 0 ),
                                 2, 0, AContainer::CO_FIX );
   ulvbhb->connect( this );
 
@@ -219,30 +219,30 @@ int ColorPanel::create()
   ac1_4_1->setMaxSpace( 0 );
 
   for ( i = 0; i < 8; i++ ) {
-    b[i][0] = (Button*)ac1_4_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 1, 0, 0 ),
+    b[i][0] = (Button*)ac1_4_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 0 ),
                                      0, i + 1, AContainer::CO_FIX );
     b[i][0]->resize( b[i][0]->getWidth(), lv->getRowHeight() );
     
-    b[i][1] = (Button*)ac1_4_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 1, 0, 0 ),
+    b[i][1] = (Button*)ac1_4_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 0 ),
                                      1, i + 1, AContainer::CO_FIX );
     b[i][1]->resize( b[i][1]->getWidth(), lv->getRowHeight() );
   }
 
   b[8][0]=NULL;
-  b[8][1] = (Button*)ac1_4_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 1, 0, 0 ),
+  b[8][1] = (Button*)ac1_4_1->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 0 ),
                                    1, 9, AContainer::CO_FIX );
   b[8][1]->resize( b[8][1]->getWidth(), lv->getRowHeight() );
 
   b[9][0] = (Button*)ac1_4_1->add( new Button( _aguix,
                                                0,
                                                0,
-                                               catalog.getLocale( 32 ), 1, 0, 0 ),
+                                               catalog.getLocale( 32 ), 0 ),
                                    0, 0, AContainer::CO_FIX );
   b[9][0]->resize( b[9][0]->getWidth(), lv->getHeaderHeight() );
   b[9][1] = (Button*)ac1_4_1->add( new Button( _aguix,
                                                0,
                                                0,
-                                               catalog.getLocale( 33 ), 1, 0, 0 ),
+                                               catalog.getLocale( 33 ), 0 ),
                                    1, 0, AContainer::CO_FIX );
   b[9][1]->resize( b[9][1]->getWidth(), lv->getHeaderHeight() );
   
@@ -267,10 +267,10 @@ int ColorPanel::create()
                                                     _baseconfig.getClockbar( 0 ),
                                                     _baseconfig.getClockbar( 1 ), false ),
                                    0, 0, AContainer::CO_INCW );
-  cbvb = (Button*)ac1_5->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 1, 0, 0 ),
+  cbvb = (Button*)ac1_5->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 0 ),
                               1, 0, AContainer::CO_FIX );
   cbvb->connect( this );
-  cbhb = (Button*)ac1_5->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 1, 0, 0 ),
+  cbhb = (Button*)ac1_5->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 0 ),
                               2, 0, AContainer::CO_FIX );
   cbhb->connect( this );
 
@@ -285,58 +285,66 @@ int ColorPanel::create()
                                                    _baseconfig.getRequest( 0 ),
                                                    _baseconfig.getRequest( 1 ), false ),
                                   0, 0, AContainer::CO_INCW );
-  rvb = (Button*)ac1_6->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 1, 0, 0 ),
+  rvb = (Button*)ac1_6->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 0 ),
                              1, 0, AContainer::CO_FIX );
   rvb->connect( this );
-  rhb = (Button*)ac1_6->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 1, 0, 0 ),
+  rhb = (Button*)ac1_6->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 0 ),
                              2, 0, AContainer::CO_FIX );
   rhb->connect( this );
 
   /*
-   * Code for textview color config
+   * Code for faces
    */
 
   ac1->add( new BevelBox( _aguix, 0, 0, 10, 2, 0 ), 0, 11, AContainer::CO_INCW );
   
-  AContainer *ac1_7 = ac1->add( new AContainer( this, 3, 3 ), 0, 12 );
-  ac1_7->setBorderWidth( 0 );
-  ac1_7->setMinSpace( 5 );
-  ac1_7->setMaxSpace( 5 );
+  AContainer *ac1_8 = ac1->add( new AContainer( this, 2, 2 ), 0, 12 );
+  ac1_8->setBorderWidth( 0 );
+  ac1_8->setMinSpace( 5 );
+  ac1_8->setMaxSpace( 5 );
 
-  WConfig::ColorDef current_cols = _baseconfig.getColorDefs();
-        
-  _tv_cols_sb = (SolidButton*)ac1_7->add( new SolidButton( _aguix, 0, 0, catalog.getLocale( 752 ),
-                                                           current_cols.getTextViewTextColor(),
-                                                           current_cols.getTextViewBackground(), false ),
-                                          0, 0, AContainer::CO_INCW );
-  _tv_fg_b = (Button*)ac1_7->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 1, 0, 0 ),
-                                  1, 0, AContainer::CO_FIX );
-  _tv_fg_b->connect( this );
-  _tv_bg_b = (Button*)ac1_7->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 1, 0, 0 ),
-                                  2, 0, AContainer::CO_FIX );
-  _tv_bg_b->connect( this );
+  ac1_8->add( new Text( _aguix, 0, 0, catalog.getLocale( 1048 ) ),
+              0, 0, AContainer::CO_INCW );
 
-  _tv_high_sb = (SolidButton*)ac1_7->add( new SolidButton( _aguix, 0, 0, catalog.getLocale( 753 ),
-                                                           current_cols.getTextViewHighlightedFG(),
-                                                           current_cols.getTextViewHighlightedBG(), false ),
-                                          0, 1, AContainer::CO_INCW );
-  _tv_hfg_b = (Button*)ac1_7->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 1, 0, 0 ),
-                                   1, 1, AContainer::CO_FIX );
-  _tv_hfg_b->connect( this );
-  _tv_hbg_b = (Button*)ac1_7->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 1, 0, 0 ),
-                                   2, 1, AContainer::CO_FIX );
-  _tv_hbg_b->connect( this );
+  m_faces_lv = ac1_8->addWidget( new FieldListView( _aguix, 0, 0, 50, 100, 0 ),
+                                 0, 1, AContainer::CO_MIN );
+  m_faces_lv->connect( this );
 
-  _tv_sel_sb = (SolidButton*)ac1_7->add( new SolidButton( _aguix, 0, 0, catalog.getLocale( 791 ),
-                                                          current_cols.getTextViewSelectionFG(),
-                                                          current_cols.getTextViewSelectionBG(), false ),
-                                         0, 2, AContainer::CO_INCW );
-  _tv_sel_fg_b = (Button*)ac1_7->add( new Button( _aguix, 0, 0, catalog.getLocale( 32 ), 1, 0, 0 ),
-                                      1, 2, AContainer::CO_FIX );
-  _tv_sel_fg_b->connect( this );
-  _tv_sel_bg_b = (Button*)ac1_7->add( new Button( _aguix, 0, 0, catalog.getLocale( 33 ), 1, 0, 0 ),
-                                      2, 2, AContainer::CO_FIX );
- _tv_sel_bg_b->connect( this );
+  m_faces_lv->setDefaultColorMode( FieldListView::PRECOLOR_ONLYACTIVE );
+  m_faces_lv->setHBarState( 2 );
+  m_faces_lv->setVBarState( 2 );
+  m_faces_lv->setNrOfFields( 3 );
+  m_faces_lv->setGlobalFieldSpace( 5 );
+  m_faces_lv->setAcceptFocus( true );
+  m_faces_lv->setDisplayFocus( true );
+  m_faces_lv->setShowHeader( true );
+  m_faces_lv->setConsiderHeaderWidthForDynamicWidth( true );
+  m_faces_lv->setFieldText( 0, catalog.getLocale( 1050 ) );
+  m_faces_lv->setFieldText( 1, catalog.getLocale( 1051 ) );
+  m_faces_lv->setFieldText( 2, catalog.getLocale( 1052 ) );
+
+  AContainer *ac1_8_1 = ac1_8->add( new AContainer( this, 1, 4 ),
+                                    1, 1 );
+  ac1_8_1->setBorderWidth( 0 );
+  ac1_8_1->setMinSpace( 5 );
+  ac1_8_1->setMaxSpace( 5 );
+
+  m_face_modify = ac1_8_1->addWidget( new Button( _aguix, 0, 0, catalog.getLocale( 1053 ), 0 ),
+                                      0, 0, AContainer::CO_INCW );
+  m_face_unset = ac1_8_1->addWidget( new Button( _aguix, 0, 0, catalog.getLocale( 1054 ), 0 ),
+                                     0, 1, AContainer::CO_INCW );
+  m_face_default = ac1_8_1->addWidget( new Button( _aguix, 0, 0, catalog.getLocale( 196 ), 0 ),
+                                       0, 2, AContainer::CO_INCW );
+
+  m_face_modify->connect( this );
+  m_face_unset->connect( this );
+  m_face_default->connect( this );
+
+  ac1->add( new Text( _aguix, 0, 0, catalog.getLocale( 1049 ) ),
+            0, 13, AContainer::CO_INCW );
+
+  m_facedb_copy = new FaceDB( _baseconfig.getFaceDB() );
+  prepareFaceLV();
 
   contMaximize( true );
   return 0;
@@ -374,14 +382,7 @@ int ColorPanel::saveValues()
   _baseconfig.setLVHeader( 1, tempconfig->getLVHeader( 1 ) );
   _baseconfig.setListerBG( tempconfig->getListerBG() );
 
-  WConfig::ColorDef current_cols = _baseconfig.getColorDefs();
-  current_cols.setTextViewTextColor( _tv_cols_sb->getFG() );
-  current_cols.setTextViewBackground( _tv_cols_sb->getBG() );
-  current_cols.setTextViewHighlightedFG( _tv_high_sb->getFG() );
-  current_cols.setTextViewHighlightedBG( _tv_high_sb->getBG() );
-  current_cols.setTextViewSelectionFG( _tv_sel_sb->getFG() );
-  current_cols.setTextViewSelectionBG( _tv_sel_sb->getBG() );
-  _baseconfig.setColorDefs( current_cols );
+  _baseconfig.setFaceDB( *m_facedb_copy );
   return 0;
 }
 
@@ -458,36 +459,12 @@ void ColorPanel::run( Widget *elem, AGMessage &msg )
         tempconfig->setRequest( 1, col );
         rsb->setBG(col);
       }
-    } else if ( msg.button.button == _tv_fg_b ) {
-        col = tempconfig->palette( _tv_cols_sb->getFG() );
-        if ( col >= 0 ) {
-            _tv_cols_sb->setFG( col );
-        }
-    } else if ( msg.button.button == _tv_bg_b ) {
-        col = tempconfig->palette( _tv_cols_sb->getBG() );
-        if ( col >= 0 ) {
-            _tv_cols_sb->setBG( col );
-        }
-    } else if ( msg.button.button == _tv_hfg_b ) {
-        col = tempconfig->palette( _tv_high_sb->getFG() );
-        if ( col >= 0 ) {
-            _tv_high_sb->setFG( col );
-        }
-    } else if ( msg.button.button == _tv_hbg_b ) {
-        col = tempconfig->palette( _tv_high_sb->getBG() );
-        if ( col >= 0 ) {
-            _tv_high_sb->setBG( col );
-        }
-    } else if ( msg.button.button == _tv_sel_fg_b ) {
-        col = tempconfig->palette( _tv_sel_sb->getFG() );
-        if ( col >= 0 ) {
-            _tv_sel_sb->setFG( col );
-        }
-    } else if ( msg.button.button == _tv_sel_bg_b ) {
-        col = tempconfig->palette( _tv_sel_sb->getBG() );
-        if ( col >= 0 ) {
-            _tv_sel_sb->setBG( col );
-        }
+    } else if ( msg.button.button == m_face_modify ) {
+        modifyFace();
+    } else if ( msg.button.button == m_face_unset ) {
+        unsetFace();
+    } else if ( msg.button.button == m_face_default ) {
+        changeToDefaultFace();
     } else {
       for ( int i = 0; i < 10; i++ ) {
         if(msg.button.button==b[i][0]) {
@@ -700,3 +677,89 @@ void ColorPanel::setLVColors( int row, int fg, int bg )
   lv->setBG( row, FieldListView::CC_ACTIVE, bg );
   lv->setBG( row, FieldListView::CC_SELACT, bg );
 }
+
+void ColorPanel::prepareFaceLV()
+{
+    auto fl = m_facedb_copy->getListOfFaces();
+
+    fl.sort();
+
+    for ( auto &face_name : fl ) {
+        int row = m_faces_lv->addRow();
+        Face f = m_facedb_copy->getFace( face_name );
+
+        m_faces_lv->setText( row, 0, f.getName() );
+
+        int col = f.getColor();
+
+        if ( col < 0 ) {
+            m_faces_lv->setText( row, 1, "unset" );
+        } else {
+            m_faces_lv->setText( row, 1, AGUIXUtils::convertToString( f.getColor() ) );
+        }
+
+        m_faces_lv->setText( row, 2, f.getParent() );
+    }
+}
+
+void ColorPanel::modifyFace()
+{
+    int row = m_faces_lv->getActiveRow();
+
+    if ( ! m_faces_lv->isValidRow( row ) ) {
+        return;
+    }
+
+    Face f = m_facedb_copy->getFace( m_faces_lv->getText( row, 0 ) );
+    int col = tempconfig->palette( f.getColor() );
+
+    if ( col >= 0 ) {
+        f.setColor( col );
+        m_facedb_copy->setFace( f );
+
+        m_faces_lv->setText( row, 1, AGUIXUtils::convertToString( f.getColor() ) );
+
+        m_faces_lv->redraw();
+    }
+}
+
+void ColorPanel::unsetFace()
+{
+    int row = m_faces_lv->getActiveRow();
+
+    if ( ! m_faces_lv->isValidRow( row ) ) {
+        return;
+    }
+
+    Face f = m_facedb_copy->getFace( m_faces_lv->getText( row, 0 ) );
+
+    f.setColor( -1 );
+    m_facedb_copy->setFace( f );
+
+    m_faces_lv->setText( row, 1, "unset" );
+
+    m_faces_lv->redraw();
+}
+
+void ColorPanel::changeToDefaultFace()
+{
+    int row = m_faces_lv->getActiveRow();
+
+    if ( ! m_faces_lv->isValidRow( row ) ) {
+        return;
+    }
+
+    Face f = m_facedb_copy->getFace( m_faces_lv->getText( row, 0 ) );
+    Face default_face = m_facedb_default.getFace( f.getName() );
+
+    f.setColor( default_face.getColor() );
+    m_facedb_copy->setFace( f );
+
+    if ( f.getColor() < 0 ) {
+        m_faces_lv->setText( row, 1, "unset" );
+    } else {
+        m_faces_lv->setText( row, 1, AGUIXUtils::convertToString( f.getColor() ) );
+    }
+
+    m_faces_lv->redraw();
+}
