@@ -1,6 +1,6 @@
 /* worker_locale.cc
  * This file belongs to Worker, a file manager for UN*X/X11.
- * Copyright (C) 2001-2017 Ralf Hoffmann.
+ * Copyright (C) 2001-2018 Ralf Hoffmann.
  * You can contact me at: ralf@boomerangsworld.de
  *   or http://www.boomerangsworld.de/worker
  *
@@ -27,8 +27,8 @@
 #include "nwc_path.hh"
 #include "datei.h"
 
-#define CATENTRY 1209
-#define CATCOMENTRY 69
+#define CATENTRY 1217
+#define CATCOMENTRY 70
 #define CATFLAGENTRY 59
 
 WorkerLocale catalog;
@@ -1315,6 +1315,14 @@ The default value here is the active entry and it's already correctly protected!
   catalog[1206]=dupstring( "The given program will be executed and the output lines will be added to a new virtual directory as files. Each output line is considered one file name. Absolute paths will be used as is, relative paths will be interpreted relatively to the current directory." );
   catalog[1207]=dupstring( "Program and arguments:" );
   catalog[1208]=dupstring( "State bar font" );
+  catalog[1209]=dupstring( "Preserve base directories in virtual dirs" );
+  catalog[1210]=dupstring( "Failed to create some of the intermediate directories of %s" );
+  catalog[1211]=dupstring( "Failed to prepare the intermediate directory information for %s" );
+  catalog[1212]=dupstring( "Toggle lock state" );
+  catalog[1213]=dupstring( "Lock tab" );
+  catalog[1214]=dupstring( "Unlock tab" );
+  catalog[1215]=dupstring( "Move to the left" );
+  catalog[1216]=dupstring( "Move to the right" );
 
 //  catalog[]=dupstring( "" );
   
@@ -1387,6 +1395,7 @@ The default value here is the active entry and it's already correctly protected!
   catalogcom[66]=dupstring( "Compare directories" );
   catalogcom[67]=dupstring( "Tab profiles" );
   catalogcom[68]=dupstring( "External virtual dir" );
+  catalogcom[69]=dupstring( "Open tab menu" );
   
   catalogflag[0]=dupstring( "String requester" );
   catalogflag[1]=dupstring( "path" );
